@@ -37,8 +37,8 @@
 # @synopsis
 #
 # \arguments{
-#   \item{con}{Binary @connection to which the MAT file structure should be
-#     written to. A string is interpreted as filename, which then will be
+#   \item{con}{Binary @connection from which the MAT file structure should be
+#     read. A string is interpreted as filename, which then will be
 #     opened (and closed afterwards).}
 #   \item{maxLength}{The maximum number of bytes to be read from the input
 #     stream, which should be equal to the length of the MAT file structure.
@@ -1290,7 +1290,8 @@ setMethodS3("readMat", "default", function(con, maxLength=NULL, fixNames=TRUE, v
             rm(unzraw);
           }, error = function(ex) {
             msg <- ex$message;
-            assign("R.matlab.debug.zraw", zraw, envir=globalenv());
+            env <- globalenv(); # To please 'R CMD check'
+            assign("R.matlab.debug.zraw", zraw, envir=env);
             msg <- sprintf("INTERNAL ERROR: Failed to decompress data (using '%s'). Please report to the R.matlab package maintainer (%s). The reason was: %s", attr(uncompress, "label"), getMaintainer(R.matlab), msg);
             onError <- getOption("R.matlab::readMat/onDecompressError");
             if (identical(onError, "warning")) {
